@@ -6,7 +6,7 @@ import appdirs
 name = "pydatasci"
 
 app_dir_free = appdirs.user_data_dir("pydatasci")
-# need to make sure there's a trailing slash
+# Adds trailing slash or backslashes depending on OS.
 app_dir = os.path.join(app_dir_free, '')
 default_config_path = app_dir + "config.json"
 default_db_path = app_dir + "aidb.sqlite3"
@@ -142,7 +142,7 @@ def get_config():
 			pds_config = json.load(pds_config_file)
 			return pds_config
 	else: 
-		print("\n=> Welcome to PyDataSci.\nConfiguration has not been set. To get started, run `pds.create_folder()` followed by `pds.create_config() in Python shell.\n")
+		print("\n=> Welcome to PyDataSci.\nTo get started, run `pds.create_folder()` followed by `pds.create_config() in Python shell.\n")
 
 
 def create_config():
